@@ -28,7 +28,7 @@ import getopt
 import rclconfig
 import cmdtalk
 
-_g_mswindows = (sys.platform == "win32")
+_g_mswindows = sys.platform == "win32"
 _g_execdir = os.path.dirname(sys.argv[0])
 
 _g_config = rclconfig.RclConfig()
@@ -51,7 +51,7 @@ def logmsg(msg):
 
 # Convert to bytes if not already such.
 def makebytes(data):
-    if type(data) == type(''):
+    if type(data) == type(""):
         return data.encode("UTF-8")
     return data
 
@@ -63,8 +63,8 @@ def subprocfile(fn):
     # we receive file names as UTF-8. So we need to convert.
     # On Unix all list elements get converted to bytes in the C _posixsubprocess module, nothing to
     # do.
-    if _g_mswindows and type(fn) != type(''):
-        return fn.decode('UTF-8')
+    if _g_mswindows and type(fn) != type(""):
+        return fn.decode("UTF-8")
     else:
         return fn
 
@@ -77,7 +77,7 @@ def configparamtrue(value):
         ivalue = int(value)
         return True if ivalue else False
     except:
-        return True if value[0] in 'tT' else False
+        return True if value[0] in "tT" else False
 
 
 # Escape special characters in plain text for inclusion in HTML doc.
@@ -87,11 +87,19 @@ def htmlescape(txt):
     # &amp must stay first (it somehow had managed to skip
     # after the next replace, with rather interesting results)
     try:
-        txt = txt.replace(b'&', b'&amp;').replace(b'<', b'&lt;').\
-              replace(b'>', b'&gt;').replace(b'"', b'&quot;')
+        txt = (
+            txt.replace(b"&", b"&amp;")
+            .replace(b"<", b"&lt;")
+            .replace(b">", b"&gt;")
+            .replace(b'"', b"&quot;")
+        )
     except:
-        txt = txt.replace("&", "&amp;").replace("<", "&lt;").\
-              replace(">", "&gt;").replace("\"", "&quot;")
+        txt = (
+            txt.replace("&", "&amp;")
+            .replace("<", "&lt;")
+            .replace(">", "&gt;")
+            .replace('"', "&quot;")
+        )
     return txt
 
 
@@ -107,6 +115,7 @@ def htmlescape(txt):
 def which(program):
     def is_exe(fpath):
         return os.path.exists(fpath) and os.access(fpath, os.X_OK)
+
     def ext_candidates(fpath):
         yield fpath
         for ext in os.environ.get("PATHEXT", "").split(os.pathsep):
@@ -132,16 +141,19 @@ def which(program):
                     return candidate
     return None
 
+
 # Execute Python script. cmd is a list with the script name as first elt.
 def execPythonScript(icmd):
     import subprocess
+
     cmd = list(icmd)
     if _g_mswindows:
         if not os.path.isabs(cmd[0]):
             cmd[0] = os.path.join(_g_execdir, cmd[0])
         cmd = [sys.executable] + cmd
     return subprocess.check_output(cmd)
-    
+
+
 # Temp dir helper
 class SafeTmpDir:
     def __init__(self, tag, em=None):
@@ -167,20 +179,19 @@ class SafeTmpDir:
                 if os.path.isfile(path):
                     os.unlink(path)
         return True
-    
+
     def getpath(self):
         if not self.tmpdir:
-            envrcltmp = os.getenv('RECOLL_TMPDIR')
+            envrcltmp = os.getenv("RECOLL_TMPDIR")
             if envrcltmp:
-                self.toptmp = tempfile.mkdtemp(prefix='rcltmp', dir=envrcltmp)
+                self.toptmp = tempfile.mkdtemp(prefix="rcltmp", dir=envrcltmp)
             else:
-                self.toptmp = tempfile.mkdtemp(prefix='rcltmp')
+                self.toptmp = tempfile.mkdtemp(prefix="rcltmp")
 
             self.tmpdir = os.path.join(self.toptmp, self.tag)
             os.makedirs(self.tmpdir)
 
         return self.tmpdir
-   
 
 
 ############################################
@@ -194,7 +205,7 @@ class RclExecM(cmdtalk.CmdTalk):
     noerror = 0
     subdocerror = 1
     fileerror = 2
-    
+
     def __init__(self):
         self.mimetype = b""
         self.fields = {}
@@ -210,8 +221,8 @@ class RclExecM(cmdtalk.CmdTalk):
         self.nodecodeinput = True
 
         super().__init__()
-        
-    def rclog(self, s, doexit = 0, exitvalue = 1):
+
+    def rclog(self, s, doexit=0, exitvalue=1):
         # On windows, and I think that it changed quite recently (Qt
         # change?), we get stdout as stderr?? So don't write at all if
         # output not a file until this mystery is solved
@@ -226,27 +237,26 @@ class RclExecM(cmdtalk.CmdTalk):
         self.fields[nm] = value
 
     # Send answer: document, ipath, possible eof.
-    def answer(self, docdata, ipath, iseof = noteof, iserror = noerror):
+    def answer(self, docdata, ipath, iseof=noteof, iserror=noerror):
         if iserror != RclExecM.fileerror and iseof != RclExecM.eofnow:
             self.fields["Document"] = docdata
             if len(ipath):
                 self.fields["Ipath"] = ipath
             if len(self.mimetype):
                 self.fields["Mimetype"] = self.mimetype
-      
+
         # If we're at the end of the contents, say so
         if iseof == RclExecM.eofnow:
-            self.fields["Eofnow"] =  b''
+            self.fields["Eofnow"] = b""
         elif iseof == RclExecM.eofnext:
-            self.fields["Eofnext"] = b''
+            self.fields["Eofnext"] = b""
         if iserror == RclExecM.subdocerror:
-            self.fields["Subdocerror"] = b''
+            self.fields["Subdocerror"] = b""
         elif iserror == RclExecM.fileerror:
-            self.fields["Fileerror"] = b''
+            self.fields["Fileerror"] = b""
 
         super().answer(self.fields)
         self.fields = {}
-  
 
     def processmessage(self, processor, params):
         # We must have a filename entry (even empty). Else exit
@@ -257,11 +267,11 @@ class RclExecM(cmdtalk.CmdTalk):
         if len(params["filename"]) != 0:
             try:
                 if not processor.openfile(params):
-                    self.answer("", "", iserror = RclExecM.fileerror)
+                    self.answer("", "", iserror=RclExecM.fileerror)
                     return
             except Exception as err:
                 self.rclog("processmessage: openfile raised: [%s]" % err)
-                self.answer("", "", iserror = RclExecM.fileerror)
+                self.answer("", "", iserror=RclExecM.fileerror)
                 return
 
         # If we have an ipath, that's what we look for, else ask for next entry
@@ -274,11 +284,11 @@ class RclExecM(cmdtalk.CmdTalk):
             else:
                 ok, data, ipath, eof = processor.getnext(params)
         except Exception as err:
-            self.rclog("getipath/next: exception: %s" %err)
+            self.rclog("getipath/next: exception: %s" % err)
             self.answer("", "", eof, RclExecM.fileerror)
             return
 
-        #self.rclog("processmessage: ok %s eof %s ipath %s"%(ok, eof, ipath))
+        # self.rclog("processmessage: ok %s eof %s ipath %s"%(ok, eof, ipath))
         if ok:
             self.answer(data, ipath, eof)
         else:
@@ -287,7 +297,6 @@ class RclExecM(cmdtalk.CmdTalk):
     # We inherit the mainloop() from cmdtalk.
 
 
-
 # Common main routine for all python execm filters: either run the
 # normal protocol engine or a local loop to test without recollindex
 def main(proto, extract):
@@ -296,14 +305,16 @@ def main(proto, extract):
         # mainloop does not return. Just in case
         sys.exit(1)
 
-
     # Not running the main loop: either acting as single filter (when called
     # from other filter for example), or debugging
     def usage():
-        print("Usage: rclexecm.py [-d] [-f] [-h] [-i ipath] [-s] <filename>", file=sys.stderr)
+        print(
+            "Usage: rclexecm.py [-d] [-f] [-h] [-i ipath] [-s] <filename>",
+            file=sys.stderr,
+        )
         print("       rclexecm.py -w <prog>", file=sys.stderr)
         sys.exit(1)
-        
+
     actAsSingle = False
     debugDumpData = False
     debugDumpFields = False
@@ -312,37 +323,37 @@ def main(proto, extract):
     args = sys.argv[1:]
     opts, args = getopt.getopt(args, "dfhi:sw:")
     for opt, arg in opts:
-        if opt in ['-d']:
+        if opt in ["-d"]:
             debugDumpData = True
-        elif opt in ['-f']:
+        elif opt in ["-f"]:
             debugDumpFields = True
-        elif opt in ['-h']:
+        elif opt in ["-h"]:
             usage()
-        elif opt in ['-i']:
+        elif opt in ["-i"]:
             ipath = makebytes(arg)
-        elif opt in ['-w']:
+        elif opt in ["-w"]:
             ret = which(arg)
             if ret:
                 print("%s" % ret)
                 sys.exit(0)
             else:
                 sys.exit(1)
-        elif opt in ['-s']:
+        elif opt in ["-s"]:
             actAsSingle = True
         else:
-            print("unknown option %s\n"%opt, file=sys.stderr)
+            print("unknown option %s\n" % opt, file=sys.stderr)
             usage()
 
     if len(args) != 1:
         usage()
     path = args[0]
-        
+
     def mimetype_with_file(f):
         cmd = 'file -i "' + f + '"'
         fileout = os.popen(cmd).read()
-        lst = fileout.split(':')
-        mimetype = lst[len(lst)-1].strip()
-        lst = mimetype.split(';')
+        lst = fileout.split(":")
+        mimetype = lst[len(lst) - 1].strip()
+        lst = mimetype.split(";")
         return makebytes(lst[0].strip())
 
     def mimetype_with_xdg(f):
@@ -351,9 +362,12 @@ def main(proto, extract):
 
     def debprint(out, s):
         if not actAsSingle:
-            proto.breakwrite(out, makebytes(s+'\n'))
+            proto.breakwrite(out, makebytes(s + "\n"))
 
-    params = {'filename' : makebytes(path)}
+    # makebytes does not work for the path arg because of possible surrogates in a non-decodable
+    # binary path: https://peps.python.org/pep-0383/
+    bpath = path.encode(sys.getfilesystemencoding(), "surrogateescape")
+    params = {"filename": bpath}
 
     # Some filters (e.g. rclaudio.py) need/get a MIME type from the indexer.
     # We make a half-assed attempt to emulate:
@@ -361,7 +375,7 @@ def main(proto, extract):
     if not mimetype and not _g_mswindows:
         mimetype = mimetype_with_file(path)
     if mimetype:
-        params['mimetype'] = mimetype
+        params["mimetype"] = mimetype
 
     if not extract.openfile(params):
         print("Open error", file=sys.stderr)
@@ -369,35 +383,41 @@ def main(proto, extract):
 
     ioout = sys.stdout.buffer
     if ipath != b"" or actAsSingle:
-        params['ipath'] = ipath
+        params["ipath"] = ipath
         ok, data, ipath, eof = extract.getipath(params)
         if ok:
-            debprint(ioout, "== Found entry for ipath %s (mimetype [%s]):" % \
-                  (ipath, proto.mimetype.decode('cp1252')))
+            debprint(
+                ioout,
+                "== Found entry for ipath %s (mimetype [%s]):"
+                % (ipath, proto.mimetype.decode("cp1252")),
+            )
             bdata = makebytes(data)
             if debugDumpData or actAsSingle:
                 proto.breakwrite(ioout, bdata)
-                ioout.write(b'\n')
+                ioout.write(b"\n")
             sys.exit(0)
         else:
-            print("Got error, eof %d"%eof, file=sys.stderr)
+            print("Got error, eof %d" % eof, file=sys.stderr)
             sys.exit(1)
 
-    ecnt = 0   
+    ecnt = 0
     while 1:
         ok, data, ipath, eof = extract.getnext(params)
         if ok:
             ecnt = ecnt + 1
             bdata = makebytes(data)
-            debprint(ioout, "== Entry %d dlen %d ipath %s (mimetype [%s]):" % \
-                  (ecnt, len(data), ipath, proto.mimetype.decode('cp1252')))
+            debprint(
+                ioout,
+                "== Entry %d dlen %d ipath %s (mimetype [%s]):"
+                % (ecnt, len(data), ipath, proto.mimetype.decode("cp1252")),
+            )
             if debugDumpFields:
-                for k,v in proto.fields.items():
-                    debprint(ioout, "  %s -> %s" % (k,v))
+                for k, v in proto.fields.items():
+                    debprint(ioout, "  %s -> %s" % (k, v))
             proto.fields = {}
             if debugDumpData:
                 proto.breakwrite(ioout, bdata)
-                ioout.write(b'\n')
+                ioout.write(b"\n")
             if eof != RclExecM.noteof:
                 sys.exit(0)
         else:
